// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import jp.ne.dti.lares.foozy.sasax.CompositeElement;
import jp.ne.dti.lares.foozy.sasax.Element;
import jp.ne.dti.lares.foozy.sasax.ElementRepetition;
import jp.ne.dti.lares.foozy.sasax.EmptyElement;

/**
 * Class to parse "rdf:Seq" element of RSS.
 *
 * <p>This has "MUST ITEM"s as shown below:</p>
 *
 * <ul>
 * <li>{@link #repetition repetition} of {@link #li "li"} element
 * </ul>
 *
 * <p>This has no "OPTIONAL ITEM".</p>
 *
 * <p>This does:</p>
 *
 * <ul>
 * <li>expect to be named as
 * {@link RDF#SEQ "Seq"} of {@link RDF#NS_URI rdf}
 * <li>not accept unknown sub elements
 * </ul>
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class RDFSeqElement
    extends CompositeElement //
{
    /**
     * Repetition of "li" element.
     */
    final
    public ElementRepetition repetition = new ElementRepetition(this);

    /**
     * Repeated "li" element.
     *
     * <p>This element does:</p>
     *
     * <ul>
     * <li>expect to be named as
     * {@link RDF#LI "li"} of {@link RDF#NS_URI rss}
     * <li>expect attribte named as
     * {@link RDF#RESOURCE "resource"} of {@link RDF#NS_URI rdf} 
     * <li>expect to be empty element
     * </ul>
     */
    final
    public EmptyElement li =
    new EmptyElement(repetition, RDF.NS_URI, RDF.LI);

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     *
     * @param parent of this element
     */
    public RDFSeqElement(Element parent){
        super(parent, RDF.NS_URI, RDF.SEQ, false, true);

        repetition.setElement(li);
        li.addNotification(EnsureRDFResource.CHECKER);

        addMustItem(repetition);
    }

    ///////////////////////////////////////////////////////////////////////////
}
